import request from '@/utils/request'

// 获取部门下拉框-列表
export function getDeptList(query) {
  return request({
    url: '/system/dept/list',
    method: 'get',
    params: query
  })
}

// 工程项目-列表
export function getProjectList(query) {
  return request({
    url: '/material/bm_project/list',
    method: 'get',
    params: query
  })
}
//工程项目--新增
export function addProject(data) {
  return request({
    url: '/material/bm_project',
    method: 'post',
    data: data
  })
}

// 工程项目详情
export function getProjectListDetail(id) {
  return request({
    url: '/material/bm_project/'+id,
    method: 'get',
  })
}

// 工程项目--修改
export function updateProject(data) {
  return request({
    url: '/material/bm_project',
    method: 'put',
    data: data
  })
}
// //工程项目--删除
export function delProject(proId) {
  return request({
    url: '/material/bm_project/' + proId,
    method: 'delete'
  })
}

// 工程项目
export function getProjectUserList(query) {
  return request({
    url: '/material/bm_unit_person/getDeptUserTree',
    method: 'get',
    params: {
      query,  
      isTree: 1 // 添加 isTree 参数
    }
  });
}
// 标段工程-列表
export function ProjectLotList(query) {
  return request({
    url: '/material/base/bmProjectLot/projectLotAll',
    method: 'get',
    params: query
  })
}
//标段工程--新增
export function addProjectLot(data) {
  return request({
    url: '/material/base/bmProjectLot',
    method: 'post',
    data: data
  })
}

// 标段工程--修改
export function updateProjectLot(data) {
  return request({
    url: '/material/base/bmProjectLot',
    method: 'put',
    data: data
  })
}
//标段工程--删除
export function delProjectLot(lotId) {
  return request({
    url: '/material/base/bmProjectLot/' + lotId,
    method: 'delete'
  })
}
//工程项目下拉数据
export function getProjectSelect(data) {
  return request({
    url: '/material/base/bmProjectInfo/getProjectLot',
    method: 'post',
    data: data
  })
}


// 往来单位详情-列表
export function unitInfoAll(id) {
  return request({
    url: '/material/bm_unit/'+ id,
    method: 'get',
  })
}
//往来单位--新增
export function addUnit(data) {
  return request({
    url: '/material/bm_unit',
    method: 'post',
    data: data
  })
}

// 往来单位--修改
export function updateUnit(data) {
  return request({
    url: '/material/bm_unit',
    method: 'put',
    data: data
  })
}
// 往来单位--删除
export function delUnit(unitId) {
  return request({
    url: '/material/bm_unit/' + unitId,
    method: 'delete'
  })
}

// 删除时获取往来单位绑定的人数
export function getUnitPerson(unitId) {
  return request({
    url: '/material/bm_unit_person/' + unitId,
    method: 'get'
  })
}

// 往来单位-人员配置-左侧人员
export function getUserList(data) {
  return request({
    url: '/system/user/deptUserTree',
    method: 'post',
    data: data
  })
}

// 往来单位-人员配置-右侧单位
export function getTypeList(query) {
  return request({
    url: '/material/bm_unit_person/list',
    method: 'get',
    params: query
  })
}

// 往来单位-人员配置-保存按钮
export function unitPersonAll(query) {
  return request({
    url: '/material/bm_unit_person/bind',
    method: 'post',
    data: query
  })
}

// 往来单位-人员配置-解绑
export function delUnitPerson(query) {
  return request({
    url: '/material/bm_unit_person/unbind',
    method: 'post',
    data: query
  })
}


// 工程管理下拉框
export function queryProDataApi(dictType) {
  return request({
    url: '/system/dict/data/type/'+ dictType,
    method: 'get',
  })
}

// 字典表数据库
// 单位类型-列表
export function unitTypeList(query) {
  return request({
    url: '/system/dict/data/list',
    method: 'get',
    params: query
  })
}

// 实施单位类型-列表
export function impUnitTypeList(query) {
  return request({
    url: '/system/dept/list',
    method: 'get',
    params: query
  })
}
// 单位类型-列表-下拉
export function unitTypeListAll(query) {
  return request({
    url: '/system/dict/data/type/bm_unit_type',
    method: 'get',
    params: query
  })
}
// 标签编号-列表
export function getMaMachineLabelApi(query) {
  return request({
    url: '/material/base/maMachineLabel/list',
    method: 'get',
    params: query
  })
}
//单位类型--新增
export function addMaMachineLabelApi(data) {
  return request({
    url: '/material/bm_unit_type',
    method: 'post',
    data: data
  })
}
// 单位类型-详情
export function unitTypeDetail(typeId) {
  return request({
    url: `/material/bm_unit_type/${typeId}`,
    method: 'get',
  })
}
//单位类型--新增
export function addUnitType(data) {
  return request({
    url: '/material/bm_unit_type',
    method: 'post',
    data: data
  })
}

// 单位类型--修改
export function updateUnitType(data) {
  return request({
    url: '/material/bm_unit_type',
    method: 'put',
    data: data
  })
}

export function statusUnitType(data) {
  return request({
    url: '/material/base/dic/status',
    method: 'put',
    params: data
  })
}

//单位类型--删除
export function delUnitType(typeIds) {
  return request({
    url: '/material/bm_unit_type/' + typeIds,
    method: 'delete'
  })
}



// 资产属性管理-列表
export function propInfoList(query) {
  return request({
    url: '/material/bm_asset_attributes/list',
    method: 'get',
    params: query
  })
}
//资产属性管理--新增
export function addPropInfo(data) {
  return request({
    url: '/material/bm_asset_attributes',
    method: 'post',
    data: data
  })
}

// 资产属性管理--修改
export function updatePropInfo(data) {
  return request({
    url: '/material/bm_asset_attributes',
    method: 'put',
    data: data
  })
}
//资产属性管理--删除
export function delPropInfo(id) {
  return request({
    url: `/material/bm_asset_attributes/${id}`,
    method: 'delete'
  })
}

// 资产属性管理-详情
export function PropDetail(id) {
  return request({
    url: '/material/bm_asset_attributes/'+ id,
    method: 'get',
  })
}



// // 资产属性配置-左侧人员
// export function getProLists(query) {
//   return request({
//     url: '/material/base/maPropInfo/lists',
//     method: 'get',
//     params: query
//   })
// }

// // 资产属性配置-右侧list
// export function getMaTypeList(query) {
//   return request({
//     url: '/material/base/maPropInfo/getMaTypeList',
//     method: 'get',
//     params: query
//   })
// }

// // 资产属性配置-保存按钮
// export function savePropInfo(query) {
//   return request({
//     url: '/material/base/maPropInfo/save',
//     method: 'post',
//     data: query
//   })
// }

// // 资产属性配置-解绑
// export function UnbindPropInfo(unitId) {
//   return request({
//     url: '/material/base/maPropSet/' + unitId,
//     method: 'delete'
//   })
// }


// 获取设备信息-qrCode
export function getMachineByQrCode(query) {
  return request({
    url: '/material/ma_machine/getHisByQrcode',
    method: 'get',
    params: query
  })
}

// 获取i8工程类型
export function getI8ProjectList(params) {
  return request({
    url: '/material/bm_project/getProjectList',
    method: 'get',
    params
  })
}

// 工程合并-工程列表
export function getProListApi(params) {
  return request({
    url: '/material/bm_project_combine/list',
    method: 'get',
    params
  })
}

// 工程合并-保存
export function combineProjectApi(data) {
  return request({
    url: '/material/bm_project_combine/combineProject',
    method: 'post',
    data
  })
}

// 协议合并-列表
export function getAgreementListApi(params) {
  return request({
    url: '/material/bm_agreement_combine/list',
    method: 'get',
    params
  })
}

// 协议合并-保存
export function combineAgreementApi(data) {
  return request({
    url: '/material/bm_agreement_combine/combineAgreement',
    method: 'post',
    data
  })
}

// 获取用户dept_id
export function getUserDeptIdApi(query) {
  return request({
    url: '/material/ma_type/getUserDeptId',
    method: 'get',
    params: query
  })
}