<template>
    <div class="app-container" id="comeAndGo">
        <el-form
            :model="queryParams"
            ref="queryForm"
            size="small"
            :inline="true"
            v-show="showSearch"
            label-width="68px"
        >
            <el-form-item label="单位名称" prop="unitName">
                <el-input
                    v-model="queryParams.unitName"
                    placeholder="请输入单位名称"
                    clearable
                    maxlength="50"
                    style="width: 240px"
                    @keyup.enter.native="handleQuery"
                />
            </el-form-item>

            <el-form-item>
                <el-button
                    type="primary"
                    icon="el-icon-search"
                    size="mini"
                    @click="handleQuery"
                    >查询</el-button
                >
                <el-button
                    icon="el-icon-refresh"
                    size="mini"
                    @click="resetQuery"
                    >重置</el-button
                >
            </el-form-item>
        </el-form>

        <el-row :gutter="10" class="mb8">
            <el-col :span="1.5">
                <el-button
                    type="primary"
                    plain
                    icon="el-icon-plus"
                    size="mini"
                    @click="handleAdd"
                    >新建</el-button
                >
            </el-col>
            <!-- <el-col :span="1.5">
                <el-button
                    type="primary"
                    plain
                    icon="el-icon-user-solid"
                    size="mini"
                    @click="handlePeople"
                    >人员配置</el-button
                >
            </el-col> -->
            <el-col :span="1.5">
                <el-button
                    type="warning"
                    plain
                    icon="el-icon-download"
                    size="mini"
                    @click="handleExport"
                    >导出数据</el-button
                >
            </el-col>

            <right-toolbar
                :showSearch.sync="showSearch"
                @queryTable="getList"
            ></right-toolbar>
        </el-row>

        <el-table
            v-loading="loading"
            :data="unitList"
            border
            @selection-change="handleSelectionChange"
        >
          <el-table-column width="60" align="center" label="序号" type="index" >
            <template slot-scope="scope">
              <span>{{ (queryParams.pageNum - 1) * queryParams.pageSize + scope.$index + 1 }}</span>
            </template>
          </el-table-column>
            <el-table-column
                label="单位名称"
                align="center"
                prop="unitName"
                :show-overflow-tooltip="true"
            />
            <el-table-column
                label="单位类型"
                align="center"
                prop="typeName"
                :show-overflow-tooltip="true"
            />
            <el-table-column
                label="所属分公司"
                align="center"
                prop="deptName"
                :show-overflow-tooltip="true"
            />
            <el-table-column
                label="联系人"
                align="center"
                prop="linkMan"
                :show-overflow-tooltip="true"
            />
            <el-table-column
                label="联系电话"
                align="center"
                prop="telphone"
                :show-overflow-tooltip="true"
            />
            <!-- <el-table-column
                label="状态"
                align="center"
                prop="status"
                width="140"
            >
                <template slot-scope="scope">
                    <el-switch
                        active-value="0"
                        inactive-value="1"
                        @change="changeStatus(scope.row)"
                        v-model="scope.row.status"
                    >
                    </el-switch>
                </template>
            </el-table-column> -->
            <el-table-column label="操作" align="center" width="140">
                <template slot-scope="scope">
                    <el-button
                        size="mini"
                        type="text"
                        icon="el-icon-edit"
                        @click="handleUpdate(scope.row)"
                        >编辑</el-button
                    >
                    <el-button
                        size="mini"
                        type="text"
                        icon="el-icon-delete"
                        @click="handleDelete(scope.row)"
                        >删除</el-button
                    >
                </template>
            </el-table-column>
        </el-table>

        <pagination
            v-show="total > 0"
            :total="total"
            :page.sync="queryParams.pageNum"
            :limit.sync="queryParams.pageSize"
            @pagination="getList"
        />

        <!-- 添加或修改参数配置对话框 -->
        <el-dialog
            :title="title"
            :visible.sync="open"
            width="600px"
            append-to-body
            :close-on-click-modal="false"
        >
            <el-form
                ref="form"
                :model="form"
                :rules="rules"
                label-width="120px"
            >
                <el-form-item label="单位名称" prop="unitName">
                    <el-input
                        v-model="form.unitName"
                        placeholder="请输入单位名称"
                        maxlength="60"
                    />
                </el-form-item>
                <el-form-item label="单位类型" prop="typeId">
                    <el-select
                        v-model="form.typeId"
                        placeholder="请选择单位类型"
                        style="width: 100%"
                        filterable
                    >
                        <el-option
                            v-for="item in typeList"
                           :key="item.value"
                           :label="item.label"
                           :value="item.value"
                        />
                    </el-select>
                </el-form-item>
                <el-form-item label="所属分公司" prop="deptId">
                    <el-select
                        v-model="form.deptId"
                        placeholder="请选择所属分公司"
                        style="width: 100%"
                        filterable
                    >
                        <el-option
                            v-for="item in deptOptions"
                           :key="item.value"
                           :label="item.label"
                           :value="item.value"
                        />
                    </el-select>
                </el-form-item>
                <el-form-item label="联系人" prop="linkMan">
                    <el-input
                        v-model="form.linkMan"
                        placeholder="请输入联系人"
                        maxlength="20"
                    />
                </el-form-item>
                <el-form-item label="联系电话" prop="telphone">
                    <el-input
                        v-model="form.telphone"
                        placeholder="请输入联系电话"
                        maxlength="11"
                    />
                </el-form-item>
            </el-form>
            <div slot="footer" class="dialog-footer">
                <el-button
                    type="primary"
                    @click="submitForm"
                    :loading="isLoading"
                    >确 定</el-button
                >
                <el-button @click="cancel">取 消</el-button>
            </div>
        </el-dialog>
    </div>
</template>

<script>
import {   unitTypeList,addUnit, delUnit,getUnitPerson, unitInfoAll, updateUnit,getTypeList,getDeptList } from '@/api/basic/basic'
import { unitTypeListAll } from '@/api/basic/basic'
import { deptTreeSelect } from '@/api/system/user'
import Treeselect from '@riophae/vue-treeselect'
import '@riophae/vue-treeselect/dist/vue-treeselect.css'
export default {
    name: 'BmUnit',
    dicts: ['sys_normal_disable'],
    components: { Treeselect },
    data() {
        return {
            isLoading: false,
            //单位类型
            typeList: [],
            chonsenData: {},
            selectType: '',
            // 部门下拉选项
            deptOptions: [],
            selectDept: '',
            // 遮罩层
            loading: true,
            // 选中数组
            ids: [],
            // 非单个禁用
            single: true,
            // 非多个禁用
            multiple: true,
            // 显示搜索条件
            showSearch: true,
            // 总条数
            total: 0,
            // 表格数据
            unitList: [],
            // 弹出层标题
            title: '',
            // 是否显示弹出层
            open: false,
            // 日期范围
            dateRange: [],
            // 查询参数
            queryParams: {
                pageNum: 1,
                pageSize: 10,
                unitName: undefined,
                dictType: undefined,
                status: undefined,
                dataCondition: [],
                typeId:undefined
            },
            // 表单参数
            form: {},
            // 表单校验
            rules: {
                unitName: [
                    {
                        required: true,
                        message: '单位名称不能为空',
                        trigger: 'blur',
                    },
                ],
                typeId: [
                    {
                        required: true,
                        message: '单位类型不能为空',
                        trigger: 'change',
                    },
                ],
                deptId: [
                    {
                        required: true,
                        message: '所属分公司不能为空',
                        trigger: 'blur',
                    },
                ],
                linkMan: [
                    { required: true, message: "联系人不能为空", trigger: "blur" },
                ],
                telphone: [
                { required: true, message: "手机号不能为空", trigger: "blur" },
                {
                    pattern: /^1[3|4|5|6|7|8|9][0-9]\d{8}$/,
                    message: "请输入正确的手机号码",
                    trigger: "blur"
                }
                ],
            },
        }
    },
    created() {
        this.getType()
         this.getTypeDept()
        // this.getDeptTree()
        this.getList()
    },
    methods: {
        //获取单位类型
        getType() {
              unitTypeList({ dictType: 'bm_unit_type', pageSize: 9999}).then((response) => {
               let unitList = response.rows
                this.typeList = unitList.map((item) => {
                return {
                label: item.dictLabel,
                value: item.dictCode,
                };
            });
            })
        },

        //获取所属分公司类型
        getTypeDept() {
            getDeptList().then((response) => {
          let unitList = response.data;
          let result=[];
          unitList.forEach(item=>{
             const parts = item.ancestors.split(',');
            if(parts.length==2){
                 result.push({
                label: item.deptName,
                value: item.deptId,
                });
            }
          })
           this.deptOptions=result

            //    let unitList = response.data
            //     this.deptOptions = unitList.map((item) => {
            //     return {
            //     label: item.deptName,
            //     value: item.deptId,
            //     };
            // });
            })
        },

        select(row) {
            // console.log(row.label)
            this.form.deptName = row.label
        },
        resetValidation() {
            this.$refs.form.clearValidate('deptId')
        },
        //更新
        changeStatus(row) {
            let param = {
                unitId: row.unitId,
                status: row.status,
            }
            updateUnit(param).then((response) => {
                this.getList()
            })
        },
        /** 查询列表 */
        getList() {
            this.loading = true
            getTypeList(this.queryParams).then((response) => {
                this.unitList = response.rows
                this.total = response.total
                this.loading = false
            })
        },
        // 取消按钮
        cancel() {
            this.open = false
            this.reset()
        },
        // 表单重置
        reset() {
            this.form = {
                unitId: undefined,
                unitName: undefined,
                dictType: undefined,
                status: '0',
                remark: undefined,
                typeId: undefined,
                typeName: undefined
            }
            this.resetForm('form')
        },
        /** 搜索按钮操作 */
        handleQuery() {
            this.queryParams.pageNum = 1
            this.getList()
        },
        /** 重置按钮操作 */
        resetQuery() {
            this.dateRange = []
            this.resetForm('queryForm')
            this.handleQuery()
        },
        /** 新增按钮操作 */
        handleAdd() {
            this.reset()
            this.open = true
            this.title = '新建'
            this.getType()
            this.getTypeDept()
        },
        handlePeople(row) {
            this.$router.push({
                path:'/basic/bmUnitPeople'
            })
        },
        // 多选框选中数据
        handleSelectionChange(selection) {
            this.ids = selection.map((item) => item.unitId)
            this.queryParams.dataCondition = this.ids
            this.single = selection.length != 1
            this.multiple = !selection.length
        },
        /** 修改按钮操作 */
        handleUpdate(row) {
            this.getType()
            this.getTypeDept()
            this.reset()
            unitInfoAll(row.unitId).then((response) => {
                this.form = response.data
                this.form.typeId = this.form.typeId
            })
            this.open = true
            this.title = '编辑'
        },
        /** 提交按钮 */
        submitForm: function () {
            this.$refs['form'].validate((valid) => {
                if (valid) {
                    this.isLoading = true
                    if (this.form.unitId != undefined) {
                        updateUnit(this.form)
                            .then((response) => {
                                this.$modal.msgSuccess('修改成功')
                                this.open = false
                                this.isLoading = false
                                this.getList()
                            })
                            .catch(() => {
                                this.isLoading = false
                            })
                    } else {
                        addUnit(this.form)
                            .then((response) => {
                                this.$modal.msgSuccess('新增成功')
                                this.open = false
                                this.isLoading = false
                                this.getList()
                            })
                            .catch(() => {
                                this.isLoading = false
                            })
                    }
                }
            })
        },
        /** 删除按钮操作 */
       async handleDelete(row) {
            const unitId = row.unitId
          await  getUnitPerson(row.unitId).then((response)=>{
                        if(response.data!=0){
                        this.$alert('存在使用人，无法删除', '提示', {
                        type: 'warning',
                        confirmButtonText: '确定',
                         });
                            return;
                        }else{
                this.$modal
                .confirm('是否确认删除所选择的数据项？')
                .then(function () {
                     return  delUnit(unitId)

                })
                .then(() => {
                    this.getList()
                    this.$modal.msgSuccess('删除成功')
                })
                .catch(() => {})
                        }
            })

        },
        /** 导出按钮操作 */
        handleExport() {
          const formatTime = (date) => {
            const year = date.getFullYear();
            const month = String(date.getMonth() + 1).padStart(2, '0');
            const day = String(date.getDate()).padStart(2, '0');
            const hours = String(date.getHours()).padStart(2, '0');
            const minutes = String(date.getMinutes()).padStart(2, '0');
            const seconds = String(date.getSeconds()).padStart(2, '0');
            return `${year}${month}${day}_${hours}${minutes}${seconds}`;
          };

          const currentTime = formatTime(new Date());
            this.download(
                'material/bm_unit/export',
                {
                    ...this.queryParams,
                },
                `往来单位_${currentTime}.xlsx`,
            )
        },
    },
}
</script>
